
# ================================ dictElements ================================

@doc raw"""
    dictElements

Source:  Standard atomic weights of the elements 2021 (IUPAC Technical Report)
#### Example:
```
dictElements
  Dict{Int64, Tuple{String, String, Any}} with 102 entries:
    5  => ("boron", "B", 10.81)
    56 => ("barium", "Ba", 137.33)
    35 => ("bromine", "Br", 79.904)
    55 => ("caesium", "Cs", 132.91)
    60 => ("neodymium", "Nd", 144.24)
    30 => ("zinc", "Zn", 65.38)
    32 => ("germanium", "Ge", 72.63)
    6  => ("carbon", "C", 12.011)
    ⋮  => ⋮
```
"""
dictElements = Dict(

         1 => ("hydrogen", "H", 1.008),
         2 => ("helium", "He", 4.0026),
         3 => ("lithium", "Li", 6.94),
         4 => ("beryllium", "Be", 9.0122),
         5 => ("boron", "B", 10.81),
         6 => ("carbon", "C", 12.011),
         7 => ("nitrogen", "N", 14.007),
         8 => ("oxygen", "O", 15.999),
         9 => ("fluorine", "F", 18.998),
        10 => ("neon", "Ne", 20.18),
        11 => ("sodium", "Na", 22.99),
        12 => ("magnesium", "Mg", 24.305),
        13 => ("aluminium", "Al", 26.982),
        14 => ("silicon", "Si", 28.085),
        15 => ("phosphorus", "P", 30.974),
        16 => ("sulfur", "S", 32.06),
        17 => ("chlorine", "Cl", 35.45),
        18 => ("argon", "Ar", 39.95),
        19 => ("potassium", "K", 39.098),
        20 => ("calcium", "Ca", 40.078),
        21 => ("scandium", "Sc", 44.956),
        22 => ("titanium", "Ti", 47.867),
        23 => ("vanadium", "V", 50.942),
        24 => ("chromium", "Cr", 51.996),
        25 => ("manganese", "Mn", 54.938),
        26 => ("iron", "Fe", 55.845),
        27 => ("cobalt", "Co", 58.933),
        28 => ("nickel", "Ni", 58.693),
        29 => ("copper", "Cu", 63.546),
        30 => ("zinc", "Zn", 65.38),
        31 => ("gallium", "Ga", 69.723),
        32 => ("germanium", "Ge", 72.63),
        33 => ("arsenic", "As", 74.922),
        34 => ("selenium", "Se", 78.971),
        35 => ("bromine", "Br", 79.904),
        36 => ("krypton", "Kr", 83.798),
        37 => ("rubidium", "Rb", 85.468),
        38 => ("strontium", "Sr", 87.62),
        39 => ("yttrium", "Y", 88.906),
        40 => ("zirconium", "Zr", 91.224),
        41 => ("niobium", "Nb", 92.906),
        42 => ("molybdenum", "Mo", 95.95),
        43 => ("technetium*", "Tc", nothing),
        44 => ("ruthenium", "Ru", 101.07),
        45 => ("rhodium", "Rh", 102.91),
        46 => ("palladium", "Pd", 106.42),
        47 => ("silver", "Ag", 107.87),
        48 => ("cadmium", "Cd", 112.41),
        49 => ("indium", "In", 114.82),
        50 => ("tin", "Sn", 118.71),
        51 => ("antimony", "Sb", 121.76),
        52 => ("tellurium", "Te", 127.6),
        53 => ("iodine", "I", 126.9),
        54 => ("xenon", "Xe", 131.29),
        55 => ("caesium", "Cs", 132.91),
        56 => ("barium", "Ba", 137.33),
        57 => ("lanthanum", "La", 138.91),
        58 => ("cerium", "Ce", 140.12),
        59 => ("praseodymium", "Pr", 140.91),
        60 => ("neodymium", "Nd", 144.24),
        61 => ("promethium*", "Pm", nothing),
        62 => ("samarium", "Sm", 150.36),
        63 => ("europium", "Eu", 151.96),
        64 => ("gadolinium", "Gd", 157.25),
        65 => ("terbium", "Tb", 158.93),
        66 => ("dysprosium", "Dy", 162.5),
        67 => ("holmium", "Ho", 164.93),
        68 => ("erbium", "Er", 167.26),
        69 => ("thulium", "Tm", 168.93),
        70 => ("ytterbium", "Yb", 173.05),
        71 => ("lutetium", "Lu", 174.97),
        72 => ("hafnium", "Hf", 178.49),
        73 => ("tantalum", "Ta", 180.95),
        74 => ("tungsten", "W", 183.84),
        75 => ("rhenium", "Re", 186.21),
        76 => ("osmium", "Os", 190.23),
        77 => ("iridium", "Ir", 192.22),
        78 => ("platinum", "Pt", 195.08),
        79 => ("gold", "Au", 196.97),
        80 => ("mercury", "Hg", 200.59),
        81 => ("thallium", "Tl", 204.38),
        82 => ("lead", "Pb", 207.2),
        83 => ("bismuth*", "Bi", 208.98),
        84 => ("polonium*", "Po", nothing),
        85 => ("astatine*", "At", nothing),
        86 => ("radon*", "Rn", nothing),
        87 => ("francium*", "Fr", nothing),
        88 => ("radium*", "Ra", nothing),
        89 => ("actinium*", "Ac", nothing),
        90 => ("thorium*", "Th", 232.04),
        91 => ("protactinium*", "Pa", 231.04),
        92 => ("uranium*", "U", 238.03),
        93 => ("neptunium*", "Np", nothing),
        94 => ("plutonium*", "Pu", nothing),
        95 => ("americium*", "Am", nothing),
        96 => ("curium*", "Cm", nothing),
        97 => ("berkelium*", "Bk", nothing),
        98 => ("californium*", "Cf", nothing),
        99 => ("einsteinium*", "Es", nothing),
       100 => ("fermium*", "Fm", nothing),
       101 => ("mendelevium*", "Md", nothing),
       102 => ("nobelium*", "No", nothing)

       )


# ======================== dictIsotopes ========================================

@doc raw"""
    dictIsotopes

Sources: AME2020, LINDC(NDS)-0794 and INDC(NDS)-0833
#### Example:
```
dictIsotopes
  Dict{Tuple{Int64, Int64}, Tuple{String, Real, Real, Real, Int64, Real, Real, Any, Any, Vararg{Nothing}}} with 340 entries:
    (71, 175) => ("Lu", 5.37, 1.74941e8, 7//2, 1, 1.0e100, 2.2257, 3.49, 97.401)
    (40, 92)  => ("Zr", 4.3057, 9.1905e7, 0, 1, 1.0e100, 0, 0, 17.15)
    (48, 111) => ("Cd", 4.5845, 1.10904e8, 1//2, 1, 1.0e100, -0.594, 0, 12.795)
    (72, 176) => ("Hf", 5.3286, 1.75941e8, 0, 1, 1.0e100, 0, 0, 5.26)
    (30, 68)  => ("Zn", 3.9658, 6.79248e7, 0, 1, 1.0e100, 0, 0, 18.45)
    (76, 184) => ("Os", 5.3823, 1.83952e8, 0, 1, 5.6e13, 0, 0, 0.02)
    (54, 129) => ("Xe", 4.7775, 1.28905e8, 1//2, 1, 1.0e100, -0.777961, 0, 26.401)
    ⋮         => ⋮
```
"""
dictIsotopes = Dict(

        (1, 1) => ("H", 0.8783,  1.007825032,      1//2, +1,      1e100, +2.792847351,  0,          99.9855),
        (1, 2) => ("H", 2.1421,  2.014101778,      1,   +1,      1e100, +0.857438231, +0.0028578,   0.0145),
        (1, 3) => ("H", 1.7591,  3.016049281,      1//2, +1,      12.33, +2.978962460,  0,          nothing),
        (2, 3) => ("He", 1.9661, 3.016029322,     1//2, +1,      1e100, -2.12762531,   0,           0.0002),
        (2, 4) => ("He", 1.6755, 4.002603254,     0,   +1,      1e100, 0,             0,          99.9998),
        (3, 6) => ("Li", 2.589,  6.015122887,      1,   +1,      1e100, +0.822043,    -0.000806,    4.85),
        (3, 7) => ("Li", 2.444,  7.016003434,      3//2, -1,      1e100, +3.256407,    -0.0400,     95.15),
        (4, 9) => ("Be", 2.519,  9.012183062,      3//2, -1,      1e100, -1.177430,    +0.0529,    100.0),
        (4, 10) => ("Be", 2.355, 10.01353469,     0,   +1,    1.51e06, 0,             0,        nothing),
        (5, 10) => ("B", 2.4277, 10.01293686,     3,   +1,      1e100, 1.8004636,    +0.0846,    19.65),
        (5, 11) => ("B", 2.406,  11.00930517,      3//2, -1,      1e100, 2.688378,     +0.04059,   80.35),
        (6, 12) => ("C", 2.4702, 12.000000,        0,   +1,      1e100, 0,             0,          98.94),
        (6, 13) => ("C", 2.4614, 13.00335484,     1//2, -1,      1e100, +0.702369,     0,           1.06),
        (6, 14) => ("C", 2.5025, 14.00324199,     0,   +1,       5700, 0,             0,        nothing),
        (7, 14) => ("N", 2.5582, 14.003074,        1,   +1,      1e100, +0.403573,    +0.02044,  99.6205),
        (7, 15) => ("N", 2.6058, 15.0001089,      1//2, -1,      1e100, -0.2830569,    0,          0.3795),
        (8, 16) => ("O", 2.6991, 15.99491462,     0,   +1,      1e100, 0,             0,          99.757),
        (8, 17) => ("O", 2.6932, 16.99913176,     5//2, +1,      1e100, -1.893543,    -0.0256,    0.03835),
        (8, 18) => ("O", 2.7726, 17.99915961,     0,   +1,      1e100, 0,             0,          0.2045),
        (9, 19) => ("F", 2.8976, 18.99840316,     1//2, +1,      1e100, +2.628321,     0,          100.00),
        (10, 20) => ("Ne", 3.0055, 19.99244018,   0,   +1,      1e100, 0,             0,          90.48),
        (10, 21) => ("Ne", 2.9695, 20.99384669,   3//2, +1,      1e100, -0.66170,     +0.1016,    0.27),
        (10, 22) => ("Ne", 2.9525, 21.99138511,   0,   +1,      1e100, 0,             0,          9.25),
        (11, 22) => ("Na", 2.9852, 21.99443755,   3,   +1,       2.60, +1.746,       +0.180,    nothing),
        (11, 23) => ("Na", 2.9936, 22.98976928,   3//2, +1,      1e100, +2.21750,     +0.104,     100.00),
        (12, 24) => ("Mg", 3.057,  23.98504169,    0,   +1,      1e100, 0,             0,          78.965),
        (12, 25) => ("Mg", 3.0284, 24.98583697,   5//2, +1,      1e100, -0.85533,     +0.199,     10.011),
        (12, 26) => ("Mg", 3.0337, 25.98259297,   0,   +1,      1e100, 0,             0,          11.025),
        (13, 26) => ("Al", 3.05,   25.98689188,     5,   +1,    7.17e5, +2.803,        +0.26,     nothing),
        (13, 27) => ("Al", 3.061,  26.98153841,    5//2, +1,      1e100, +3.64070,      +0.1466,    100.00),
        (14, 28) => ("Si", 3.1224, 27.97692653,   0,   +1,      1e100, 0,             0,          92.2545),
        (14, 29) => ("Si", 3.1176, 28.97649466,   1//2, +1,      1e100, -0.555052,     0,          4.672),
        (14, 30) => ("Si", 3.1336, 29.97377014,   0,   +1,      1e100, 0,             0,          3.0735),
        (15, 31) => ("P", 3.1889,  30.973762,       1//2, +1,      1e100, +1.130925,     0,          100.00),
        (16, 32) => ("S", 3.2611,  31.97207117,    0,   +1,      1e100, 0,             0,          94.85),
        (16, 33) => ("S", 3.3,     32.97145891,       3//2, +1,      1e100, +0.64325,     -0.0678,    0.763),
        (16, 34) => ("S", 3.2847,  33.96786701,    0,   +1,      1e100, 0,             0,          4.365),
        (16, 36) => ("S", 3.2985,  35.96708069,    0,   +1,      1e100, 0,             0,          0.0158),
        (17, 35) => ("Cl", 3.3654, 34.96885269,   3//2, +1,      1e100, +0.82170,      -0.817,     75.8),
        (17, 36) => ("Cl", 3.37,   35.96830682,     2,   +1,    3.01e5, 1.2849,        -0.178,     nothing),
        (17, 37) => ("Cl", 3.384,  36.96590257,    3//2, +1,      1e100, +0.6840,      -0.0644,    24.2),
        (18, 36) => ("Ar", 3.3905, 35.96754511,   0,   +1,      1e100, 0,             0,          0.3336),
        (18, 38) => ("Ar", 3.4028, 37.9627321,    0,   +1,      1e100, 0,             0,          0.0629),
        (18, 39) => ("Ar", 3.4093, 38.96431304,   7//2, -1,       269, -1.590,         -0.116,    nothing),
        (18, 40) => ("Ar", 3.4274, 39.96238312,   0,   +1,      1e100, 0,             0,          99.6035),
        (19, 39) => ("K", 3.4349,  38.96370648,    3//2, +1,      1e100, +0.391470,     +0.0603,    93.2581),
        (19, 40) => ("K", 3.4381,  39.96399817,    4,   -1,    1.25e9, -1.29797,      -0.0750,    0.0117),
        (19, 41) => ("K", 3.4518,  40.96182526,    3//2, +1,      1e100, +0.21482,     -0.0734,    6.7302),
        (20, 40) => ("Ca", 3.4776, 39.96259085,   0,   +1,      1e100, 0,             0,          96.941),
        (20, 41) => ("Ca", 3.478,  40.96227791,    7//2, -1,    1.00e5, -1.5942,        -0.665,    nothing),
        (20, 42) => ("Ca", 3.5081, 41.95861778,   0,   +1,      1e100, 0,             0,          0.647),
        (20, 43) => ("Ca", 3.4954, 42.95876638,   7//2, -1,      1e100, -1.31733,      -0.0408,    0.135),
        (20, 44) => ("Ca", 3.5179, 43.95548149,   0,   +1,      1e100, 0,             0,          2.086),
        (20, 46) => ("Ca", 3.4953, 45.95368773,   0,   +1,      1e100, 0,             0,          0.004),
        (20, 48) => ("Ca", 3.4771, 47.95252265,   0,   +1,    2.90e19, 0,             0,          0.187),
        (21, 45) => ("Sc", 3.5459, 44.95590705,   7//2, -1,    4.00e19, +4.75400,     -0.220,    100.00),
        (22, 46) => ("Ti", 3.607,  45.95262636,    0,   +1,      1e100, 0,             0,          8.25),
        (22, 47) => ("Ti", 3.5962, 46.95175749,   5//2, -1,      1e100, -0.78848,     +0.302,    7.44),
        (22, 48) => ("Ti", 3.5921, 47.94794068,   0,   +1,      1e100, 0,             0,          73.72),
        (22, 49) => ("Ti", 3.5733, 48.94786439,   7//2, -1,      1e100, -1.10417,      0.247,      5.41),
        (22, 50) => ("Ti", 3.5704, 49.94478562,   0,   +1,      1e100, 0,             0,          5.18),
        (23, 50) => ("V",  3.5800, 49.94715668,   6,   +1,    2.65e17, +3.3456889,    +0.21,      0.25),
        (23, 51) => ("V",  3.6002, 50.94395766,   7//2, -1,      1e100, +5.1464,      -0.52,      99.75),
        (24, 50) => ("Cr", 3.6588, 49.94604221,   0,   +1,    1.30e18, 0,             0,          4.345),
        (24, 52) => ("Cr", 3.6452, 51.94050471,   0,   +1,      1e100, 0,             0,          83.789),
        (24, 53) => ("Cr", 3.6511, 52.9406463,    3//2, -1,      1e100, -0.47431,      -0.15,      9.501),
        (24, 54) => ("Cr", 3.6885, 53.93887736,   0,   +1,      1e100, 0,              0,         2.365),
        (25, 53) => ("Mn", 3.6662, 52.9412875,    7//2, -1,    3.70e06, +5.033,       +0.17,      nothing),
        (25, 55) => ("Mn", 3.7057, 54.93804304,   5//2, -1,      1e100, 3.4669,        +0.330,    100.00),
        (26, 54) => ("Fe", 3.6933, 53.93960819,   0,   +1,      1e100, 0,             0,          5.845),
        (26, 56) => ("Fe", 3.7377, 55.93493554,   0,   +1,      1e100, 0,             0,          91.754),
        (26, 57) => ("Fe", 3.7532, 56.93539195,   1//2, -1,      1e100, 0.09064,       0,          2.119),
        (26, 58) => ("Fe", 3.7745, 57.93327358,   0,   +1,      1e100, 0,             0,          0.282),
        (26, 60) => ("Fe", 3.7800, 59.93407025,   0,   +1,    2.62e06, 0,             0,          nothing),
        (27, 59) => ("Co", 3.7875, 58.93319352,   7//2, -1,      1e100, +4.615,       +0.42,     100.00),
        (27, 60) => ("Co", 3.7900, 59.93381554,   5,   +1,    1925.28, +3.799,       +0.46,      nothing),
        (28, 58) => ("Ni", 3.7757, 57.93534165,   0,   +1,      1e100, 0,             0,          68.0769),
        (28, 60) => ("Ni", 3.8118, 59.93078513,   0,   +1,      1e100, 0,             0,          26.2231),
        (28, 61) => ("Ni", 3.8225, 60.93105482,   3//2, -1,      1e100, -0.74965,      +0.162,     1.1399),
        (28, 62) => ("Ni", 3.8399, 61.92834475,   0,   +1,      1e100, 0,             0,          3.6345),
        (28, 64) => ("Ni", 3.8572, 63.92796623,   0,   +1,      1e100, 0,             0,          0.9256),
        (29, 63) => ("Cu", 3.8823, 62.92959712,   3//2, -1,      1e100, +2.2259,       -0.220,     69.15),
        (29, 65) => ("Cu", 3.9022, 64.92778948,   3//2, -1,      1e100, 2.3844,        -0.204,     30.85),
        (30, 64) => ("Zn", 3.9283, 63.92914178,   0,   +1,      1e100, 0,             0,         49.17),
        (30, 66) => ("Zn", 3.9491, 65.92603364,   0,   +1,      1e100, 0,             0,         27.73),
        (30, 67) => ("Zn", 3.953,  66.92712742,    5//2, -1,      1e100, +0.87485,     +0.122,      4.04),
        (30, 68) => ("Zn", 3.9658, 67.92484423,   0,   +1,      1e100, 0,             0,         18.45),
        (30, 70) => ("Zn", 3.9845, 69.92531918,   0,   +1,    3.80e18, 0,             0,         0.61),
        (31, 69) => ("Ga", 3.9973, 68.92557353,   3//2, -1,      1e100, +2.01502,     +0.171,     60.108),
        (31, 71) => ("Ga", 4.0118, 70.92470255,   3//2, -1,      1e100, +2.56033,     +0.107,     39.892),
        (32, 70) => ("Ge", 4.0414, 69.92424854,   0,   +1,      1e100, 0,             0,         20.52),
        (32, 72) => ("Ge", 4.0576, 71.92207582,   0,   +1,      1e100, 0,             0,         27.45),
        (32, 73) => ("Ge", 4.0632, 72.92345895,   9//2, +1,      1e100, -0.87824,     -0.196,    7.76),
        (32, 74) => ("Ge", 4.0742, 73.92117776,   0,   +1,      1e100, 0,             0,         36.52),
        (32, 76) => ("Ge", 4.0811, 75.92140273,   0,   +1,      1e100, 0,             0,         7.75),
        (33, 75) => ("As", 4.0968, 74.92159456,   3//2, -1,      1e100, +1.4383,      +0.311,     100.00),
        (34, 74) => ("Se", 4.07,   73.92247593,     0,   +1,      1e100, 0,             0,         0.86),
        (34, 76) => ("Se", 4.1395, 75.9192137,    0,   +1,      1e100, 0,             0,         9.23),
        (34, 77) => ("Se", 4.1395, 76.91991415,   1//2, -1,      1e100, +0.53356,      0,         7.6),
        (34, 78) => ("Se", 4.1406, 77.91730924,   0,   +1,      1e100, 0,             0,         23.69),
        (34, 79) => ("Se", 4.14,   78.91849925,     7//2, +1,    3.27e05, -1.018,        nothing,   nothing),
        (34, 80) => ("Se", 4.14,   79.91652176,     0,   +1,      1e100, 0,             0,         49.8),
        (35, 79) => ("Br", 4.1629, 78.91833757,   3//2, -1,      1e100, +2.1046,      +0.3087,    50.65),
        (35, 81) => ("Br", 4.1599, 80.9162882,    3//2, -1,      1e100, +2.2686,      +0.2579,    49.35),
        (36, 78) => ("Kr", 4.2038, 77.92036634,   0,   +1,      1e100, 0,             0,         0.355),
        (36, 80) => ("Kr", 4.197,  79.91637794,    0,   +1,      1e100, 0,             0,         2.286),
        (36, 81) => ("Kr", 4.1952, 80.9165897,    7//2, +1,    2.29e05, -0.907,       +0.644,     nothing),
        (36, 82) => ("Kr", 4.1919, 81.91348115,   0,   +1,      1e100, 0,             0,         11.593),
        (36, 83) => ("Kr", 4.1871, 82.91412652,   9//2, +1,      1e100, -0.970730,    +0.259,     11.5),
        (36, 84) => ("Kr", 4.1884, 83.91149773,   0,   +1,      1e100, 0,             0,         56.987),
        (36, 85) => ("Kr", 4.1846, 84.91252726,   9//2, +1,      10.74, -1.0055,      +0.433,     nothing),
        (36, 86) => ("Kr", 4.1835, 85.91061062,   0,   +1,      1e100, 0,             0,         17.279),
        (37, 85) => ("Rb", 4.2036, 84.91178974,   5//2, -1,      1e100, +1.35306,     +0.276,     72.17),
        (37, 87) => ("Rb", 4.1989, 86.90918053,   3//2, -1,    4.97e10, +2.75129,     +0.1335,    27.83),
        (38, 84) => ("Sr", 4.2394, 83.91341912,   0,   +1,      1e100, 0,             0,         0.56),
        (38, 86) => ("Sr", 4.2307, 85.90926072,   0,   +1,      1e100, 0,             0,         9.86),
        (38, 87) => ("Sr", 4.2249, 86.90887749,   9//2, +1,      1e100, -1.09316,     +0.305,     7),
        (38, 88) => ("Sr", 4.224,  87.90561225,    0,   +1,      1e100, 0,             0,         82.58),
        (39, 89) => ("Y",  4.243,  88.90583816,    1//2, -1,      1e100, -0.137298,     0,         100.00),
        (40, 90) => ("Zr", 4.2694, 89.90469876,   0,   +1,      1e100, 0,             0,         51.45),
        (40, 91) => ("Zr", 4.2845, 90.90564021,   5//2, +1,      1e100, -1.3022,      -0.176,     11.22),
        (40, 92) => ("Zr", 4.3057, 91.90503534,   0,   +1,      1e100, 0,             0,         17.15),
        (40, 94) => ("Zr", 4.332,  93.90631252,    0,   +1,      1e100, 0,             0,         17.38),
        (40, 96) => ("Zr", 4.3512, 95.90827762,   0,   +1,    2.00e19, 0,             0,         2.8),
        (41, 91) => ("Nb", 4.28,   90.90699026,     9//2, +1,        680, +6.513,       -0.25,      nothing),
        (41, 92) => ("Nb", 4.3026, 91.90718858,   7,   +1,    3.47e07, +5.130,       -0.35,      nothing),
        (41, 93) => ("Nb", 4.324,  92.90637317,    9//2, +1,      1e100, +6.163,       -0.32,      100.00),
        (42, 92) => ("Mo", 4.3151, 91.90680715,   0,   +1,      1e100, 0,             0,         14.649),
        (42, 94) => ("Mo", 4.3529, 93.90508359,   0,   +1,      1e100, 0,             0,         9.187),
        (42, 95) => ("Mo", 4.3628, 94.90583744,   5//2, +1,      1e100, -0.9132,      -0.022,    15.873),
        (42, 96) => ("Mo", 4.3847, 95.90467477,   0,   +1,      1e100, 0,             0,         16.673),
        (42, 97) => ("Mo", 4.388,  96.9060169,     5//2, +1,      1e100, -0.9324,      +0.255,     9.582),
        (42, 98) => ("Mo", 4.4091, 97.90540361,   0,   +1,      1e100, 0,             0,         24.292),
        (42, 100) => ("Mo", 4.4468, 99.90746798,  0,   +1,    7.01e18, 0,             0,         9.744),
        (43, 99) => ("Tc", 4.4,     98.90624968,      9//2, +1,    2.11e5, +5.678,        -0.129,     nothing),
        (44, 96) => ("Ru", 4.3908,  95.90758891,   0,   +1,      1e100, 0,             0,         5.54),
        (44, 98) => ("Ru", 4.4229,  97.90528671,   0,   +1,      1e100, 0,             0,         1.87),
        (44, 99) => ("Ru", 4.4338,  98.90593028,   5//2, +1,      1e100, -0.641,       +0.079,     12.76),
        (44, 100) => ("Ru", 4.4531, 99.90421046,  0,   +1,      1e100, 0,             0,         12.6),
        (44, 101) => ("Ru", 4.4606, 100.9055731,  5//2, +1,      1e100, -0.718,       +0.46,      17.06),
        (44, 102) => ("Ru", 4.4809, 101.9043403,  0,   +1,      1e100, 0,             0,         31.55),
        (44, 104) => ("Ru", 4.5098, 103.9054253,  0,   +1,      1e100, 0,             0,         18.62),
        (45, 103) => ("Rh", 4.4945, 102.9054941,  1//2, -1,      1e100, -0.08829,      0,         100.00),
        (46, 102) => ("Pd", 4.4827, 101.9056323,  0,   +1,      1e100, 0,             0,         1.02),
        (46, 104) => ("Pd", 4.5078, 103.9040304,  0,   +1,      1e100, 0,             0,         11.14),
        (46, 105) => ("Pd", 4.515,  104.9050795,   5//2, +1,      1e100, -0.642,        0.660,     22.33),
        (46, 106) => ("Pd", 4.5318, 105.9034803,  0,   +1,      1e100, 0,             0,         27.33),
        (46, 108) => ("Pd", 4.5563, 107.9038918,  0,   +1,      1e100, 0,             0,         26.46),
        (46, 110) => ("Pd", 4.5782, 109.9051729,  0,   +1,      1e100, 0,             0,         11.72),
        (47, 107) => ("Ag", 4.5454, 106.9050915,  1//2, -1,      1e100, -0.11352,      0,         51.839),
        (47, 109) => ("Ag", 4.5638, 108.9047558,  1//2, -1,      1e100, 0.13051,       0,         48.161),
        (48, 106) => ("Cd", 4.5383, 105.9064598,  0,   +1,      1e100, 0,             0,         1.245),
        (48, 108) => ("Cd", 4.5577, 107.9041836,  0,   +1,      1e100, 0,             0,         0.888),
        (48, 110) => ("Cd", 4.5765, 109.9030075,  0,   +1,      1e100, 0,             0,         12.47),
        (48, 111) => ("Cd", 4.5845, 110.9041838,  1//2, +1,      1e100, -0.5940,       0,         12.795),
        (48, 112) => ("Cd", 4.5944, 111.9027639,  0,   +1,      1e100, 0,             0,         24.109),
        (48, 113) => ("Cd", 4.6012, 112.9044081,  1//2, +1,    8.04e15, -0.6213,       0,         12.227),
        (48, 114) => ("Cd", 4.6087, 113.903365,    0,   +1,      1e100, 0,             0,         28.754),
        (48, 116) => ("Cd", 4.6203, 115.9047632,  0,   +1,    3.30e19, 0,             0,         7.512),
        (49, 113) => ("In", 4.601,  112.9040605,   9//2, +1,      1e100, +5.5208,       0.761,     4.281),
        (49, 115) => ("In", 4.6156, 114.9038788,  9//2, +1,    4.41e14, +5.5326,       0.772,     95.719),
        (50, 112) => ("Sn", 4.5948, 111.9048249,  0,   +1,      1e100, 0,             0,         0.97),
        (50, 114) => ("Sn", 4.6099, 113.9027801,  0,   +1,      1e100, 0,             0,         0.66),
        (50, 115) => ("Sn", 4.6148, 114.9033447,  1//2, +1,      1e100, -0.9174,       0,         0.340),
        (50, 116) => ("Sn", 4.625,  115.9017428,   0,   +1,      1e100, 0,             0,         14.54),
        (50, 117) => ("Sn", 4.6302, 116.902954,    1//2, +1,      1e100, -0.9995,       0,         7.680),
        (50, 118) => ("Sn", 4.6393, 117.9016066,  0,   +1,      1e100, 0,             0,         24.22),
        (50, 119) => ("Sn", 4.6438, 118.9033113,  1//2, +1,      1e100, -1.0459,       0,         8.59),
        (50, 120) => ("Sn", 4.6519, 119.9022026,  0,   +1,      1e100, 0,             0,         32.58),
        (50, 122) => ("Sn", 4.6634, 121.9034455,  0,   +1,      1e100, 0,             0,         4.63),
        (50, 124) => ("Sn", 4.6735, 123.9052796,  0,   +1,      1e100, 0,             0,         5.79),
        (51, 121) => ("Sb", 4.6802, 120.9038114,  5//2, +1,      1e100, +3.3580,      -0.543,     57.21),
        (51, 123) => ("Sb", 4.6879, 122.9042153,  7//2, +1,      1e100, +2.5457,      -0.692,     42.79),
        (52, 120) => ("Te", 4.7038, 119.9040658,  0,   +1,      1e100, 0,             0,         0.09),
        (52, 122) => ("Te", 4.7095, 121.9030447,  0,   +1,      1e100, 0,             0,         2.55),
        (52, 123) => ("Te", 4.7117, 122.904271,    1//2, +1,    9.20e16, -0.7358,       0,         0.89),
        (52, 124) => ("Te", 4.7183, 123.9028183,  0,   +1,      1e100, 0,             0,         4.74),
        (52, 125) => ("Te", 4.7204, 124.9044312,  1//2, +1,      1e100, -0.8870,       0,         7.07),
        (52, 126) => ("Te", 4.7266, 125.9033121,  0,   +1,      1e100, 0,             0,         8.84),
        (52, 128) => ("Te", 4.7346, 127.9044612,  0,   +1,    7.70e24, 0,             0,         31.74),
        (52, 130) => ("Te", 4.7423, 129.9062227,  0,   +1,    7.90e20, 0,             0,         34.08),
        (53, 127) => ("I", 4.75,    126.9044726,     5//2, +1,      1e100, +2.8087,      -0.688,     100.00),
        (53, 129) => ("I", 4.8,     128.9049836,      7//2, +1,     1.57e7, +2.6165,      -0.483,     nothing),
        (54, 124) => ("Xe", 4.7661, 123.9058852,  0,   +1,    1.60e14, 0,             0,         0.095),
        (54, 126) => ("Xe", 4.7722, 125.9042974,  0,   +1,      1e100, 0,             0,         0.089),
        (54, 128) => ("Xe", 4.7774, 127.9035308,  0,   +1,      1e100, 0,             0,         1.91),
        (54, 129) => ("Xe", 4.7775, 128.9047809,  1//2, +1,      1e100, -0.777961,     0,         26.401),
        (54, 130) => ("Xe", 4.7818, 129.9035093,  0,   +1,      1e100, 0,             0,         4.071),
        (54, 131) => ("Xe", 4.7808, 130.9050841,  3//2, +1,      1e100, +0.691845,    -0.114,     21.232),
        (54, 132) => ("Xe", 4.7859, 131.9041551,  0,   +1,      1e100, 0,             0,         26.909),
        (54, 134) => ("Xe", 4.7899, 133.905393,    0,   +1,    5.80e22, 0,             0,         10.436),
        (54, 136) => ("Xe", 4.7964, 135.9072145,  0,   +1,    2.17e21, 0,             0,         8.857),
        (55, 133) => ("Cs", 4.8041, 132.905452,    7//2, +1,      1e100, +2.5778,      -0.00343,   100.00),
        (55, 134) => ("Cs", 4.805,  133.9286804,   4,   +1,       2.06, +2.9893,      +0.37,      nothing),
        (55, 135) => ("Cs", 4.8067, 134.9059769,  7//2, +1,     2.30e6, +2.7283,      +0.048,     nothing),
        (55, 137) => ("Cs", 4.807,  136.946162,     7//2, +1,       30.1, +2.8374,      +0.048,     nothing),
        (56, 130) => ("Ba", 4.8283, 129.906326,    0,   +1,      1e100, 0,             0,         0.11),
        (56, 132) => ("Ba", 4.8303, 131.9050612,  0,   +1,    3.00e21, 0,             0,         0.1),
        (56, 134) => ("Ba", 4.8322, 133.9045082,  0,   +1,      1e100, 0,             0,         2.42),
        (56, 135) => ("Ba", 4.8294, 134.9056884,  3//2, +1,      1e100, +0.8381,      +0.153,     6.59),
        (56, 136) => ("Ba", 4.8334, 135.9045758,  0,   +1,      1e100, 0,             0,         7.85),
        (56, 137) => ("Ba", 4.8314, 136.9058272,  3//2, +1,      1e100, +0.9375,      +0.236,     11.23),
        (56, 138) => ("Ba", 4.8378, 137.9052471,  0,   +1,      1e100, 0,             0,         71.7),
        (57, 137) => ("La", 4.8496, 136.9064504,  7//2, +1,     6.00e4, +2.696,       +0.21,      nothing),
        (57, 138) => ("La", 4.8473, 137.907124,    5, +1,      1.03e11, +3.7084,      +0.39,      0.08881),
        (57, 139) => ("La", 4.855,  138.9063629,   7//2, +1,      1e100, +2.7791,       0.206,     99.91119),
        (58, 136) => ("Ce", 4.8739, 135.9071293,  0,   +1,      1e100, 0,             0,         0.186),
        (58, 138) => ("Ce", 4.8737, 137.9059942,  0,   +1,    4.40e16, 0,             0,         0.251),
        (58, 140) => ("Ce", 4.8771, 139.9054484,  0,   +1,      1e100, 0,             0,         88.449),
        (58, 142) => ("Ce", 4.9063, 141.9092502,  0,   +1,    5.00e16, 0,             0,         11.114),
        (59, 141) => ("Pr", 4.8919, 140.9076596,  5//2, +1,      1e100, +4.266,       -0.077,     100.00),
        (60, 142) => ("Nd", 4.9123, 141.9077288,  0,   +1,      1e100, 0,             0,         27.153),
        (60, 143) => ("Nd", 4.9254, 142.9098198,  7//2, -1,      1e100, -1.065,       -0.61,      12.173),
        (60, 144) => ("Nd", 4.9421, 143.9100928,  0,   +1,    2.29e15, 0,             0,         23.798),
        (60, 145) => ("Nd", 4.9535, 144.9125792,  7//2, -1,      1e100, -0.656,       -0.314,     8.293),
        (60, 146) => ("Nd", 4.9696, 145.9131225,  0,   +1,      1e100, 0,             0,         17.189),
        (60, 148) => ("Nd", 4.9999, 147.916899,    0,   +1,      1e100, 0,             0,         5.756),
        (60, 150) => ("Nd", 5.04,   149.9209013,  0,   +1,    9.10e18, 0,             0,         5.638),
        (61, 147) => ("Pm", 5.0,    146.9151449,  7//2, +1,      2.623, +2.58,        +0.74,      nothing),
        (62, 144) => ("Sm", 4.9524, 143.9120063,  0,   +1,      1e100, 0,             0,         3.08),
        (62, 146) => ("Sm", 4.9808, 145.9130468,  0,   +1,    6.80e07, 0,             0,         nothing),
        (62, 147) => ("Sm", 4.9892, 146.9149044,  7//2, -1,    1.07e11, -0.8090,      -0.26,      15),
        (62, 148) => ("Sm", 5.0042, 147.9148292,  0,   +1,    7.00e15, 0,             0,         11.25),
        (62, 149) => ("Sm", 5.0134, 148.9171912,  7//2, -1,      1e100, -0.6677,      +0.078,     13.82),
        (62, 150) => ("Sm", 5.0387, 149.917282,    0,   +1,      1e100, 0,             0,         7.37),
        (62, 151) => ("Sm", 5.055,  150.9199389,   5//2, -1,         90, -0.3605,      +0.71,      0.0057),
        (62, 152) => ("Sm", 5.0819, 151.9197386,  0,   +1,      1e100, 0,             0,         26.74),
        (62, 154) => ("Sm", 5.1053, 153.9222158,  0,   +1,      1e100, 0,             0,         22.74),
        (63, 150) => ("Eu", 5.0296, 149.9197071,  5,   -1,       36.9, +2.702,       +1.13,      0.0108),
        (63, 151) => ("Eu", 5.0522, 150.9198566,  5//2, +1,     1.70e18, +3.4635,     +0.903,     47.81),
        (63, 153) => ("Eu", 5.1115, 152.9212368,  5//2, +1,       1e100, +1.5294,     +2.41,      52.19),
        (63, 153) => ("Eu", 5.1115, 152.9212368,  5//2, +1,       1e100, +1.5294,     +2.41,      0.0062),
        (63, 154) => ("Eu", 5.1239, 153.9229857,  3,   -1,       8.601, -2.000,      +2.85,      0.0079),
        (63, 155) => ("Eu", 5.1221, 154.9228998,  5//2, +1,       4.753, +1.516,      +2.5,       0.0069),
        (64, 152) => ("Gd", 5.0774, 151.9197984,  0,   +1,     1.08e14, 0,            0,          0.2),
        (64, 154) => ("Gd", 5.1223, 153.920873,    0,   +1,       1e100, 0,            0,          2.18),
        (64, 155) => ("Gd", 5.1319, 154.9226294,  3//2, -1,       1e100, -0.2591,      1.27,       14.8),
        (64, 156) => ("Gd", 5.142,  155.9221301,   0,   +1,       1e100, 0,            0,          20.47),
        (64, 157) => ("Gd", 5.1449, 156.9239674,  3//2, -1,       1e100, -0.3398,     +1.36,       15.65),
        (64, 158) => ("Gd", 5.1569, 157.9241112,  0,   +1,       1e100, 0,            0,          24.84),
        (64, 160) => ("Gd", 5.1734, 159.9270612,  0,   +1,       1e100, 0,            0,          21.86),
        (65, 157) => ("Tb", 5.0489, 156.9240319,  3//2, +1,          71, +2.03,       +1.40,       0.15),
        (65, 159) => ("Tb", 5.06,   158.9253537,    3//2, +1,       1e100, +2.009,      +1.432,      100.00),
        (66, 156) => ("Dy", 5.1622, 155.9242836,  0,   +1,       1e100, 0,            0,          0.056),
        (66, 158) => ("Dy", 5.1815, 157.9244148,  0,   +1,       1e100, 0,            0,          0.095),
        (66, 160) => ("Dy", 5.1951, 159.9252036,  0,   +1,       1e100, 0,            0,          2.329),
        (66, 161) => ("Dy", 5.1962, 160.9269394,  5//2, +1,       1e100, -0.479,      +2.51,       18.889),
        (66, 162) => ("Dy", 5.2074, 161.9268045,  0,   +1,       1e100, 0,            0,          25.475),
        (66, 163) => ("Dy", 5.2099, 162.9287372,  5//2, -1,       1e100, +0.671,      +2.65,       24.896),
        (66, 164) => ("Dy", 5.2218, 163.9291808,  0,   +1,       1e100, 0,            0,          28.26),
        (67, 163) => ("Ho", 5.1907, 162.9287403,  7//2, -1,        4570, +4.22,       +3.7,        nothing),
        (67, 165) => ("Ho", 5.2022, 164.9303291,  7//2, -1,       1e100, +4.16,       +3.58,       100.00),
        (68, 162) => ("Er", 5.2246, 161.9287873,  0,   +1,       1e100, 0,            0,          0.139),
        (68, 164) => ("Er", 5.2389, 163.9292077,  0,   +1,       1e100, 0,            0,          1.601),
        (68, 166) => ("Er", 5.2516, 165.9303011,  0,   +1,       1e100, 0,            0,          33.503),
        (68, 167) => ("Er", 5.256,  166.9320562,   7//2, +1,       1e100, -0.5623,     +3.57,       22.869),
        (68, 168) => ("Er", 5.2644, 167.9323783,  0,   +1,       1e100, 0,            0,          26.978),
        (68, 170) => ("Er", 5.2789, 169.9354719,  0,   +1,       1e100, 0,            0,          14.91),
        (69, 169) => ("Tm", 5.2256, 168.934219,    1//2, +1,       1e100, -0.2310,      0,          100.00),
        (69, 171) => ("Tm", 5.2388, 170.9364352,  1//2, +1,        1.92, -0.230,       0,          nothing),
        (70, 168) => ("Yb", 5.2702, 167.9338913,  0,   +1,       1e100, 0,            0,          0.123),
        (70, 170) => ("Yb", 5.2853, 169.9347672,  0,   +1,       1e100, 0,            0,          2.982),
        (70, 171) => ("Yb", 5.2906, 170.9363315,  1//2, -1,       1e100, +0.4923,      0,          14.086),
        (70, 172) => ("Yb", 5.2995, 171.9363867,  0,   +1,       1e100, 0,            0,          21.686),
        (70, 173) => ("Yb", 5.3046, 172.9382162,  5//2, -1,       1e100, -0.6780,     +2.80,       16.103),
        (70, 174) => ("Yb", 5.3108, 173.9388675,  0,   +1,       1e100, 0,            0,          32.025),
        (70, 176) => ("Yb", 5.3215, 175.9425747,  0,   +1,       1e100, 0,            0,          12.995),
        (71, 173) => ("Lu", 5.3577, 172.9389357,  7//2, +1,        1.37, +2.273,      +3.53,       nothing),
        (71, 174) => ("Lu", 5.3634, 173.9403428,  1,   -1,        3.31, +1.982,      +0.773,      nothing),
        (71, 175) => ("Lu", 5.37,   174.9407772,    7//2, +1,       1e100, +2.2257,     +3.49,       97.401),
        (71, 176) => ("Lu", 5.3739, 175.9426917,  7,   -1,     3.76e10, +3.160,      +4.92,       2.599),
        (72, 174) => ("Hf", 5.3201, 173.9400484,  0,   +1,     2.00e15, 0,            0,          0.16),
        (72, 176) => ("Hf", 5.3286, 175.9414098,  0,   +1,       1e100, 0,            0,          5.26),
        (72, 177) => ("Hf", 5.3309, 176.9432302,  7//2, -1,       1e100, +0.7910,     +3.37,       18.6),
        (72, 178) => ("Hf", 5.3371, 177.9437083,  0,   +1,       1e100, 0,            0,          27.28),
        (72, 179) => ("Hf", 5.3408, 178.9458257,  9//2, +1,       1e100, -0.6389,     +3.79,       13.62),
        (72, 180) => ("Hf", 5.347,  179.9465595,   0,   +1,       1e100, 0,            0,          35.08),
        (72, 182) => ("Hf", 5.3516, 181.9505637,  0,   +1,     8.90e06, 0,            0,          nothing),
        (73, 179) => ("Ta", 5.3,    178.9459391,  7//2, +1,        1.82, +2.286,      +3.27,       nothing),
        (73, 181) => ("Ta", 5.3507, 180.9479985,  7//2, +1,       1e100, +2.365,      +3.17,       99.98799),
        (74, 180) => ("W", 5.3491,  179.9467133,   0,   +1,     1.80e18, 0,            0,          0.12),
        (74, 182) => ("W", 5.3559,  181.9482056,   0,   +1,       1e100, 0,            0,          26.5),
        (74, 183) => ("W", 5.3611,  182.9502244,   1//2, -1,     6.70e20, +0.11739,     0,          14.31),
        (74, 184) => ("W", 5.3658,  183.9509332,   0,   +1,       1e100, 0,            0,          30.64),
        (74, 186) => ("W", 5.3743,  185.9543651,   0,   +1,       1e100, 0,            0,          28.43),
        (75, 185) => ("Re", 5.3596, 184.9529583,  5//2, +1,       1e100, +3.176,      +2.07,       37.4),
        (75, 187) => ("Re", 5.3698, 186.9557522,  5//2, +1,     4.33e10, +3.209,      +1.94,       62.6),
        (76, 184) => ("Os", 5.3823, 183.9524929,  0,   +1,     5.60e13, 0,            0,          0.02),
        (76, 186) => ("Os", 5.3909, 185.9538376,  0,   +1,     2.00e15, 0,            0,          1.59),
        (76, 187) => ("Os", 5.3933, 186.9557496,  1//2, -1,       1e100, +0.06442,     0,          1.96),
        (76, 188) => ("Os", 5.3993, 187.9558373,  0,   +1,       1e100, 0,            0,          13.24),
        (76, 189) => ("Os", 5.4016, 188.9581459,  3//2, -1,       1e100, +0.6576,     +0.86,       16.15),
        (76, 190) => ("Os", 5.4062, 189.9584454,  0,   +1,       1e100, 0,            0,          26.26),
        (76, 192) => ("Os", 5.4126, 191.9614788,  0,   +1,       1e100, 0,            0,          40.78),
        (77, 191) => ("Ir", 5.3968, 190.9605915,  3//2, +1,       1e100, +0.1502,     +0.8,        37.3),
        (77, 193) => ("Ir", 5.4032, 192.9629238,  3//2, +1,       1e100, +0.1630,     +0.7,        62.7),
        (78, 190) => ("Pt", 5.4108, 189.9599498,  0,   +1,     4.97e11, 0,            0,          0.012),
        (78, 192) => ("Pt", 5.4169, 191.9610427,  0,   +1,       1e100, 0,            0,          0.782),
        (78, 193) => ("Pt", 5.4191, 192.9629845,  1//2, -1,          50, +0.601,       0,          nothing),
        (78, 194) => ("Pt", 5.4236, 193.9626835,  0,   +1,       1e100, 0,            0,          32.864),
        (78, 195) => ("Pt", 5.427,  194.9647943,   1//2, -1,       1e100, +0.6073,      0,          33.775),
        (78, 196) => ("Pt", 5.4307, 195.9649546,  0,   +1,       1e100, 0,            0,          25.211),
        (78, 198) => ("Pt", 5.4383, 197.9678967,  0,   +1,       1e100, 0,            0,          7.356),
        (79, 197) => ("Au", 5.4371, 196.9665701,  3//2, +1,       1e100, +0.1452,     +0.547,      100.00),
        (80, 196) => ("Hg", 5.4385, 195.9658334,  0,   +1,       1e100, 0,            0,          0.15),
        (80, 198) => ("Hg", 5.4463, 197.9667692,  0,   +1,       1e100, 0,            0,          10.04),
        (80, 199) => ("Hg", 5.4474, 198.968281,    1//2, -1,       1e100, +0.5039,      0,          16.94),
        (80, 200) => ("Hg", 5.4551, 199.9683269,  0,   +1,       1e100, 0,            0,          23.14),
        (80, 201) => ("Hg", 5.4581, 200.9703031,  3//2, -1,       1e100, -0.5580,     +0.387,      13.17),
        (80, 202) => ("Hg", 5.4648, 201.9706436,  0,   +1,       1e100, 0,            0,          9.74),
        (80, 204) => ("Hg", 5.4744, 203.973494,    0,   +1,       1e100, 0,            0,          6.82),
        (81, 203) => ("Tl", 5.4666, 202.9723441,  1//2, +1,       1e100, +1.616,       0,          29.515),
        (81, 205) => ("Tl", 5.4759, 204.9744273,  1//2, +1,       1e100, +1.632,       0,          70.485),
        (82, 202) => ("Pb", 5.4705, 201.9721516,  0,   +1,     5.25e04, 0,            0,          nothing),
        (82, 204) => ("Pb", 5.4803, 203.9730435,  0,   +1,     1.40e17, 0,            0,          1.4),
        (82, 205) => ("Pb", 5.4828, 204.9744817,  5//2, -1,     1.70e07, +0.7094,     +0.23,       nothing),
        (82, 206) => ("Pb", 5.4902, 205.9744652,  0,   +1,       1e100, 0,            0,          24.1),
        (82, 207) => ("Pb", 5.4943, 206.9758968,  1//2, -1,       1e100, +0.5906,      0,          22.1),
        (82, 208) => ("Pb", 5.5012, 207.976652,    0,   +1,       1e100, 0,            0,          52.4),
        (83, 207) => ("Bi", 5.5103, 206.9784706,  9//2, -1,       31.55, 4.0729,      -0.76,       nothing),
        (83, 208) => ("Bi", 5.5147, 207.9797421,  5,   +1,     3.68e05, +4.572,      -0.70,       nothing),
        (83, 209) => ("Bi", 5.5211, 208.9803986,  9//2, -1,     2.01e19, +4.092,      -0.516,      100.00),
        (84, 209) => ("Po", 5.5628, 208.9824304,  1//2, -1,         124, 0.68,         0,          nothing),
        (89, 227) => ("Ac", 5.6,    227.0277506,  3//2, -1,      21.772, +1.1,        +1.74,       nothing),
        (90, 229) => ("Th", 5.7557, 229.0317614,  5//2, +1,        7880, +0.46,       +3.11,       nothing),
        (90, 230) => ("Th", 5.767,  230.0331323,   0,   +1,     7.54e04, 0,            0,          0.02),
        (90, 232) => ("Th", 5.7848, 232.0380536,  0,   +1,     1.40e10, 0,            0,          99.98),
        (91, 231) => ("Pa", 5.8,    231.0358825,  3//2, -1,     3.28e04, 1.99,        -1.72,       100.00),
        (92, 233) => ("U", 5.8203,  233.0396343,   5//2, +1,     1.59e05, -0.59,        3.663,      nothing),
        (92, 234) => ("U", 5.8291,  234.0409503,   0,   +1,     2.46e05, 0,            0,          0.0054),
        (92, 235) => ("U", 5.8337,  235.0439281,   7//2, -1,     7.04e08, -0.38,        4.936,      0.7204),
        (92, 236) => ("U", 5.8431,  236.0455661,   0,   +1,     2.34e07, 0,            0,          nothing),
        (92, 238) => ("U", 5.8571,  238.0507869,   0,   +1,     4.47e09, 0,            0,          99.2742),
        (93, 237) => ("Np", 5.85,   237.0481716,   5//2, +1,     2.14e06, +3.16,       +3.886,      nothing),
        (94, 239) => ("Pu", 5.8601, 239.0521616,  1//2, +1,       24110, +0.202,       0,          nothing),
        (94, 240) => ("Pu", 5.8701, 240.0538117,  0,   +1,        6561, 0,            0,          nothing),
        (94, 241) => ("Pu", 5.8748, 241.0568497,  5//2, +1,      14.329, -0.678,      +6,          nothing),
        (94, 242) => ("Pu", 5.8823, 242.058741,    0,   +1,     3.75e05, 0,            0,          nothing),
        (94, 244) => ("Pu", 5.8948, 244.0642044,  0,   +1,     8.13e07, 0,            0,          nothing),
        (95, 241) => ("Am", 5.8928, 241.0568273,  5//2, -1,       432.6, 1.60,        +4.34,       nothing),
        (95, 243) => ("Am", 5.9048, 243.0613799,  5//2, -1,        7364, +1.52,       +4.32,       nothing)

        )
